@@ -1,12 +1,6 @@
 from getpass import getpass
-import json
-import os
 import sys
 
-os.environ.setdefault("DJANGO_SETTINGS_MODULE", "pyportify.settings")
-import django
-django.setup()
-
 from pyportify import views as app
 
 try:
@@ -33,9 +27,7 @@ def main():
         print "Invalid Spotify username/password"
         sys.exit(1)
 
-    playlists = app.spotify_playlists(None)
-    playlists = json.loads(playlists.content)["data"]
-
+    playlists = app.fetch_spotify_playlists()
     app.transfer_playlists(playlists)
 
 
